@@ -7,7 +7,9 @@
 #' project. But contrary to \code{\link{readAntares}}, it only reads time series
 #' stored in the input folder, so it can work in "input" mode. 
 #' 
+#' @param areas vector of areas names for which thermal time series must be read.
 #' @param clusters vector of clusters names for which thermal time series must be read.
+#' @param thermalAvailabilities if TRUE, return thermalAvailabilities data
 #' @param thermalModulation if TRUE, return thermalModulation data
 #' @param thermalData if TRUE, return thermalData from prepro
 #' @inheritParams readAntares
@@ -27,13 +29,24 @@
 #' \code{\link{getAreas}}, \code{\link{getLinks}}
 #' 
 #' @export
-readInputThermal <- function(clusters = NULL, thermalModulation = FALSE, thermalData = FALSE,
+readInputThermal <- function(areas = "all",
+                             clusters,
+                             thermalAvailabilities = TRUE,
+                             thermalModulation = FALSE,
+                             thermalData = FALSE,
                              opts = simOptions(),
                              timeStep = c("hourly", "daily", "weekly", "monthly", "annual"),
-                             simplify = TRUE, parallel = FALSE,
+                             simplify = TRUE,
+                             parallel = FALSE,
                              showProgress = TRUE) {
   
+  if(!any(thermalAvailabilities, thermalModulation, thermalData)){
+    stop("At least one type of data should be selected")
+  }
+  
   timeStep <- match.arg(timeStep)
+  areas <- tolower(unique(areas))
+  clusters <- tolower(unique(clusters))
   
   # Can the importation be parallelized ?
   if (parallel) {
@@ -41,46 +54,73 @@ readInputThermal <- function(clusters = NULL, thermalModulation = FALSE, thermal
     if (!foreach::getDoParRegistered()) stop("Parallelized importation impossible. Please register a parallel backend, for instance with function 'registerDoParallel'")
   }
   
-  allAreasClusters <- readClusterDesc(opts = opts)[area %in% opts$areasWithClusters, c("area", "cluster")]
-  allClusters <- unique(allAreasClusters$cluster)
-  # Manage special value "all"
-  if(identical(clusters, "all")) clusters <- allClusters
-
-  if (length(setdiff(tolower(clusters), tolower(allClusters))) > 0){
-    cat(c("the following clusters are not available : ",setdiff(tolower(clusters), tolower(allClusters))))
-    stop("Some clusters are not available in the areas specified")
+  allAreasClusters <- readClusterDesc(opts = opts)[, c("area", "cluster")]
+  
+  #To compare with area and cluster selected
+  allAreasClusters$lower_area <- tolower(allAreasClusters$area)
+  allAreasClusters$lower_cluster <- tolower(allAreasClusters$cluster)
+  
+  if (identical(areas, "all")) {
+    areas <- allAreasClusters$area
+  }else{
+    # Check for unavailable areas
+    diff_areas <- setdiff(areas, allAreasClusters$lower_area)
+    if (length(diff_areas) > 0) {
+      stop(paste0("the following areas are not available:", diff_areas))
+    }
   }
+  # All areas selected with corresponding clusters
+  allAreasClusters_filtered_area <- allAreasClusters[area %in% areas]
+  
+  if (identical(clusters, "all")) {
+    clusters <- allAreasClusters_filtered_area$cluster
+  }else{
+    # Check for unavailable clusters
+    diff_clusters <- setdiff(clusters, allAreasClusters_filtered_area$lower_cluster)
+    if (length(diff_clusters) > 0) {
+      stop(paste0("the following clusters are not available:", diff_clusters))
+    }
+  }
+  # Couple areas/clusters of interest.
+  allAreasClusters_filtered <- allAreasClusters_filtered_area[cluster %in% clusters]
+  
+  # To loop
+  clusters <- unique(allAreasClusters_filtered$cluster)
   
-  ind_cluster <- which(tolower(allClusters) %in% tolower(clusters))
-  clusters <- unique(allClusters[ind_cluster])
   res <- list() # Object the function will return
   
-  thermalTS <- as.data.table(ldply(clusters, function(cl) {
+  # ThermalAvailabilities processing (/series)
+  if (thermalAvailabilities){
+    thermalTS <- as.data.table(ldply(clusters, function(cl) {
+      areas <- allAreasClusters_filtered[cluster == cl]$area
+      resCl <- ldply(areas, function(x){
+        filePattern <- sprintf("%s/%s/%%s/series.txt", "thermal/series", x)
+        mid <- .importInputTS(cl, timeStep, opts, filePattern, "ThermalAvailabilities",
+                              inputTimeStep = "hourly", type = "matrix")
+        
+        if (is.null(mid)){
+          nb_rows_ts <- opts$timeIdMax
+          timeId_value <- seq(1,nb_rows_ts)
+          tsId_value <- replicate(nb_rows_ts,1)
+          ThermalAvailabilities_value <- replicate(nb_rows_ts,0)
+          mid <- data.table("timeId" = timeId_value, "tsId" = tsId_value, "ThermalAvailabilities" = ThermalAvailabilities_value)
+        }
+        mid$area <- x
+        mid$cluster <- cl
+        mid
+      })
+      resCl <- dcast(as.data.table(resCl), area + cluster + timeId ~ tsId, value.var = "ThermalAvailabilities")
+    }))
     
-    area <- unique(allAreasClusters[cluster == cl]$area)
-    if (length(area) > 1) warning(cl," is in more than one area")
-    resCl <- ldply(area, function(x){
-      filePattern <- sprintf("%s/%s/%%s/series.txt", "thermal/series", x)
-      mid <- .importInputTS(cl, timeStep, opts, filePattern, "ThermalAvailabilities",
-                            inputTimeStep = "hourly", type = "matrix")
-      if (is.null(mid)) return (data.table())
-      mid$area <- x
-      mid$cluster <- cl
-      mid
-    })
+    tsCols <- setdiff(colnames(thermalTS), c("area", "cluster", "timeId"))
+    setnames(thermalTS, tsCols, paste0("ts",tsCols))
+    setcolorder(thermalTS, c("area", "cluster", "timeId", setdiff(names(thermalTS), c("area", "cluster", "timeId"))))
     
-    resCl <- dcast(as.data.table(resCl), area + cluster + timeId ~ tsId, value.var = "ThermalAvailabilities")
-  }))
+    if (nrow(thermalTS) > 0) res$thermalAvailabilities <- thermalTS
+  }
   
-  tsCols <- setdiff(colnames(thermalTS), c("area", "cluster", "timeId"))
-  setnames(thermalTS, tsCols, paste0("ts",tsCols))
-  setcolorder(thermalTS, c("area", "cluster", "timeId", setdiff(names(thermalTS), c("area", "cluster", "timeId"))))
-  
-  if (nrow(thermalTS) > 0) res$thermalAvailabilities <- thermalTS
-  
-  # thermalModulation processing
+  # thermalModulation processing (/prepro/.../.../modulation.txt)
   if (thermalModulation){
-    areas <- unique(allAreasClusters[cluster %in% clusters]$area)
     thermalMod <- as.data.table(ldply(areas, .importThermalModulation, opts = opts, timeStep = timeStep))
     thermalMod <- thermalMod[cluster %in% clusters]
     setcolorder(thermalMod, c("area", "cluster", "timeId", setdiff(names(thermalMod), c("area", "cluster", "timeId"))))
@@ -88,21 +128,21 @@ readInputThermal <- function(clusters = NULL, thermalModulation = FALSE, thermal
     if (nrow(thermalMod) > 0) res$thermalModulation <- thermalMod
   }
   
-  # thermalData processing
+  # thermalData processing (/prepro/.../.../data.txt)
   if (thermalData){
-    areas <- unique(allAreasClusters[cluster %in% clusters]$area)
     thermalDat <- as.data.table(ldply(areas, .importThermalData, opts = opts, timeStep = timeStep))
     thermalDat <- thermalDat[cluster %in% clusters]
     setcolorder(thermalDat, c("area", "cluster", "timeId", setdiff(names(thermalDat), c("area", "cluster", "timeId"))))
     
     if (nrow(thermalDat) > 0) res$thermalData <- thermalDat
   }
-    
+  
   if (length(res) == 0) stop("At least one argument of readInputTS has to be defined.")
   
   # Class and attributes
   res <- .addClassAndAttributes(res, NULL, timeStep, opts, simplify)
   addDateTimeColumns(res)
+  
 }
 
 
@@ -115,6 +155,7 @@ readInputThermal <- function(clusters = NULL, thermalModulation = FALSE, thermal
 #' project. But contrary to \code{\link{readAntares}}, it only reads time series
 #' stored in the input folder, so it can work in "input" mode. 
 #' 
+#' @param areas vector of RES areas names for which renewable time series must be read.
 #' @param clusters vector of RES clusters names for which renewable time series must be read.
 #' @inheritParams readAntares
 #' 
@@ -126,12 +167,17 @@ readInputThermal <- function(clusters = NULL, thermalModulation = FALSE, thermal
 #' \code{\link{getAreas}}, \code{\link{getLinks}}
 #' 
 #' @export
-readInputRES <- function(clusters = NULL, opts = simOptions(),
+readInputRES <- function(areas = "all",
+                         clusters,
+                         opts = simOptions(),
                          timeStep = c("hourly", "daily", "weekly", "monthly", "annual"),
-                         simplify = TRUE, parallel = FALSE,
+                         simplify = TRUE,
+                         parallel = FALSE,
                          showProgress = TRUE) {
   
   timeStep <- match.arg(timeStep)
+  areas <- tolower(unique(areas))
+  clusters <- tolower(unique(clusters))
   
   # Can the importation be parallelized ?
   if (parallel) {
@@ -140,28 +186,48 @@ readInputRES <- function(clusters = NULL, opts = simOptions(),
   }
   
   allAreasClusters <- readClusterResDesc(opts = opts)[area %in% opts$areasWithResClusters, c("area", "cluster")]
-  allClusters <- unique(allAreasClusters$cluster)
-  # Manage special value "all"
-  if(identical(clusters, "all")) clusters <- allClusters
+  allAreasClusters$lower_area <- tolower(allAreasClusters$area)
+  allAreasClusters$lower_cluster <- tolower(allAreasClusters$cluster)
   
-  if (length(setdiff(tolower(clusters), tolower(allClusters))) > 0){
-    cat(c("the following clusters are not available : ",setdiff(tolower(clusters), tolower(allClusters))))
-    stop("Some clusters are not available in the areas specified")
+  if (identical(areas, "all")) {
+    areas <- allAreasClusters$area
+  }else{
+    # Check for unavailable areas
+    diff_areas <- setdiff(areas, allAreasClusters$lower_area)
+    if (length(diff_areas) > 0) {
+      stop(paste0("the following areas are not available:", diff_areas))
+    }
   }
+  allAreasClusters_filtered_area <- allAreasClusters[area %in% areas]
+  
+  if (identical(clusters, "all")) {
+    clusters <- allAreasClusters_filtered_area$cluster
+  }else{
+    # Check for unavailable clusters
+    diff_clusters <- setdiff(clusters, allAreasClusters_filtered_area$lower_cluster)
+    if (length(diff_clusters) > 0) {
+      stop(paste0("the following clusters are not available:", diff_clusters))
+    }
+  }
+  allAreasClusters_filtered <- allAreasClusters_filtered_area[cluster %in% clusters]
+  clusters <- unique(allAreasClusters_filtered$cluster)
   
-  ind_cluster <- which(tolower(allClusters) %in% tolower(clusters))
-  clusters <- unique(allClusters[ind_cluster])
   res <- list() # Object the function will return
   
   ResTS <- as.data.table(ldply(clusters, function(cl) {
     
-    area <- unique(allAreasClusters[cluster == cl]$area)
-    if (length(area) > 1) warning(cl," is in more than one area")
-    resCl <- ldply(area, function(x){
+    areas <- allAreasClusters_filtered[cluster == cl]$area
+    resCl <- ldply(areas, function(x){
       filePattern <- sprintf("%s/%s/%%s/series.txt", "renewables/series", x)
       mid <- .importInputTS(cl, timeStep, opts, filePattern, "production",
                             inputTimeStep = "hourly", type = "matrix")
-      if (is.null(mid)) return (data.table())
+      if (is.null(mid)){
+        nb_rows_ts <- opts$timeIdMax
+        timeId_value <- seq(1,nb_rows_ts)
+        tsId_value <- replicate(nb_rows_ts,1)
+        production_value <- replicate(nb_rows_ts,0)
+        mid <- data.table("timeId" = timeId_value, "tsId" = tsId_value, "production" = production_value)
+      }
       mid$area <- x
       mid$cluster <- cl
       mid
